@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -28,12 +28,17 @@ include("../WidgetFactory.js");
  * \param document RDocument the layer is in.
  * \param layer RLayer object to edit or undefined to show a dialog for a new layer.
  */
-function LayerDialog(document, layer) {
+function LayerDialog(documentInterface, layer) {
     this.dialog = null;
-    this.document = document;
+    this.documentInterface = documentInterface;
+    this.document = undefined;
+    if (!isNull(this.documentInterface)) {
+        this.document = documentInterface.getDocument();
+    }
     this.layer = layer;
     this.prefix = undefined;
-    this.defaultName = "layer %1";
+    this.defaultName = qsTr("layer", "default layer name prefix") + " %1";
+    this.defaultColor = RSettings.getColor("Layer/DefaultColor", new RColor("black"));
 }
 
 /**
@@ -61,15 +66,13 @@ LayerDialog.prototype.getLayerName = function(dialog) {
 
 LayerDialog.prototype.show = function() {
     this.dialog = WidgetFactory.createDialog("scripts/Layer", "LayerDialog.ui");
-    //this.dialog.windowIcon = new QIcon("scripts/Layer/EditLayer/EditLayer.svg");
 
     var widgets = getWidgets(this.dialog);
     var leLayerName = widgets["LayerName"];
-    var rx = new RegExp("[^<>/\\\\\":;\?\*|,=`]{1,255}");
-    this.validator = new QRegExpValidator(rx, leLayerName);
+    this.validator = createValidator("[^<>/\\\\\":;\?\*|,=`]{1,255}", leLayerName);
     leLayerName.setValidator(this.validator);
     var cbColor = widgets["Color"];
-    cbColor.setColor(RSettings.getColor("Layer/DefaultColor", new RColor("black")));
+    cbColor.setColor(this.defaultColor);
     var cbLineweight = widgets["Lineweight"];
     cbLineweight.setLineweight(RSettings.getIntValue("Layer/DefaultLineweight", RLineweight.Weight025));
     var cbLinetype = widgets["Linetype"];
@@ -107,7 +110,7 @@ LayerDialog.prototype.show = function() {
         lLayerName.text = lLayerName.text + " " + this.prefix;
     }
 
-    leLayerName.textChanged.connect(this, "validate");
+    leLayerName.textChanged.connect(this, this.validate);
 
     this.initDialog(this.dialog, this.layer);
 
@@ -127,7 +130,7 @@ LayerDialog.prototype.show = function() {
     leLayerName.selectAll();
 
     if (!this.dialog.exec()) {
-        this.dialog.destroy();
+        destrDialog(this.dialog);
         EAction.activateMainWindow();
         return undefined;
     }
@@ -148,11 +151,10 @@ LayerDialog.prototype.show = function() {
         this.initLayer(this.dialog, this.layer);
         return this.layer;
     }
-    //this.dialog.setAttribute(Qt.WA_DeleteOnClose);
-    //this.dialog.close();
+
     var layer = new RLayer(this.document, text, false, false, clr, ltId, lw);
     this.initLayer(this.dialog, layer);
-    this.dialog.destroy();
+    destrDialog(this.dialog);
     EAction.activateMainWindow();
 
     return layer;
